You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@synapse.apache.org by ru...@apache.org on 2010/09/22 16:54:15 UTC

svn commit: r1000013 - /synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java

Author: ruwan
Date: Wed Sep 22 14:54:15 2010
New Revision: 1000013

URL: http://svn.apache.org/viewvc?rev=1000013&view=rev
Log:
fixing a typo

Modified:
    synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java

Modified: synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java
URL: http://svn.apache.org/viewvc/synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java?rev=1000013&r1=1000012&r2=1000013&view=diff
==============================================================================
--- synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java (original)
+++ synapse/branches/2.0/modules/core/src/main/java/org/apache/synapse/config/SynapsePropertiesLoader.java Wed Sep 22 14:54:15 2010
@@ -88,11 +88,11 @@ public class SynapsePropertiesLoader {
     /**
      * Load a value of the property from the synapse properties
      *
      * @param key           Key of the property
      * @param deafaultValue Default value
      * @return Value of the propoerty
      */
-    public static String getPropertyValue(String key, String deafaultValue) {
-        return MiscellaneousUtil.getProperty(loadSynapseProperties(), key, deafaultValue);
+    public static String getPropertyValue(String key, String defaultValue) {
+        return MiscellaneousUtil.getProperty(loadSynapseProperties(), key, defaultValue);
     }
 }
@@ -88,11 +88,11 @@ public class SynapsePropertiesLoader {
      * Load a value of the property from the synapse properties
      *
-     * @param key           Key of the property
-     * @param deafaultValue Default value
-     * @return Value of the propoerty
+     * @param key Key of the property
+     * @param defaultValue Default value
+     * @return Value of the property
      */